
Position
=====================
.. autoclass:: kw6.Position
   :members:
   :undoc-members:
   :member-order: bysource

.. autoclass:: kw6.PositionHeader
   :members:
   :undoc-members:
   :member-order: bysource
